@@ -347,8 +347,8 @@ xchat_plugin_init (xchat_plugin *plugin_handle, char **plugin_name, char **plugi
 	if (success) {
 		xchat_hook_print (ph, "Motd",         XCHAT_PRI_NORM, connected_cb, NULL);
 		xchat_hook_print (ph, "MOTD Skipped", XCHAT_PRI_NORM, connected_cb, NULL);
-
-		xchat_set_context (ph, xchat_find_context (ph, NULL, NULL));
+		
+		xchat_find_set_context (ph);
 		xchat_printf (ph, _("%s loaded successfully\n"), NET_MONITOR_NAME);
 	}
 	return success;
