@@ -90,8 +90,11 @@ got_focus_cb (GtkWidget * widget, GdkEventFocus * event, gpointer data)
 
 	update_tray ();
 
+#if GTK_CHECK_VERSION (2, 15, 0)
+	gtk_status_icon_set_tooltip_text (status_icon, NULL);
+#else
 	gtk_status_icon_set_tooltip (status_icon, NULL);
-
+#endif
 	return FALSE;
 }
 
@@ -180,6 +183,9 @@ xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name, char **plug
 
 	ph = plugin_handle;
 
+	/* Set context on ph*/
+	xchat_find_set_context (ph);
+
 	/* Set the plugin info. */
 	xchat_plugin_get_info (plugin_name, plugin_desc, plugin_version, NULL);
 
@@ -202,7 +208,6 @@ xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name, char **plug
 	xchat_hook_print (ph, "Channel Msg Hilight",		XCHAT_PRI_NORM, new_msg_cb, GUINT_TO_POINTER (NOTIF_NICK));
 	xchat_hook_print (ph, "Channel Action Hilight",		XCHAT_PRI_NORM, new_msg_cb, GUINT_TO_POINTER (NOTIF_NICK));
 	xchat_hook_print (ph, "Private Message to Dialog",	XCHAT_PRI_NORM, new_msg_cb, GUINT_TO_POINTER (NOTIF_NICK));
-
 	gconf_notify_id = gconf_client_notify_add (client, "/apps/xchat/plugins/notification/level", (GConfClientNotifyFunc) level_changed, NULL, NULL, NULL);
 	g_object_unref (client);
 
