@@ -16,7 +16,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include <config.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
@@ -240,6 +239,7 @@ plugin_add (session *sess, char *filename, void *handle, void *init_func,
 		pl->xchat_commandf = xchat_commandf;
 		pl->xchat_nickcmp = xchat_nickcmp;
 		pl->xchat_set_context = xchat_set_context;
+		pl->xchat_find_set_context = xchat_find_set_context;
 		pl->xchat_find_context = xchat_find_context;
 		pl->xchat_get_context = xchat_get_context;
 		pl->xchat_get_info = xchat_get_info;
@@ -416,6 +416,11 @@ plugin_auto_load_cb (char *filename)
 {
 	char *pMsg;
 
+#ifndef WIN32	/* black listed */
+	if (!strcmp (file_part (filename), "dbus.so"))
+		return;
+#endif
+
 	pMsg = plugin_load (ps, filename, NULL);
 	if (pMsg)
 	{
@@ -611,7 +616,7 @@ plugin_timeout_cb (xchat_hook *hook)
 	ret = ((xchat_timer_cb *)hook->callback) (hook->userdata);
 
 	/* the callback might have already unhooked it! */
-	if (!g_slist_find (hook_list, hook))
+	if (!g_slist_find (hook_list, hook) || hook->type == HOOK_DELETED)
 		return 0;
 
 	if (ret == 0)
@@ -649,7 +654,7 @@ plugin_insert_hook (xchat_hook *new_hook)
 static gboolean
 plugin_fd_cb (GIOChannel *source, GIOCondition condition, xchat_hook *hook)
 {
-	int flags = 0;
+	int flags = 0, ret;
 	typedef int (xchat_fd_cb2) (int fd, int flags, void *user_data, GIOChannel *);
 
 	if (condition & G_IO_IN)
@@ -659,7 +664,19 @@ plugin_fd_cb (GIOChannel *source, GIOCondition condition, xchat_hook *hook)
 	if (condition & G_IO_PRI)
 		flags |= XCHAT_FD_EXCEPTION;
 
-	return ((xchat_fd_cb2 *)hook->callback) (hook->pri, flags, hook->userdata, source);
+	ret = ((xchat_fd_cb2 *)hook->callback) (hook->pri, flags, hook->userdata, source);
+
+	/* the callback might have already unhooked it! */
+	if (!g_slist_find (hook_list, hook) || hook->type == HOOK_DELETED)
+		return 0;
+
+	if (ret == 0)
+	{
+		hook->tag = 0; /* avoid fe_input_remove, returning 0 is enough! */
+		xchat_unhook (hook->pl, hook);
+	}
+
+	return ret;
 }
 
 /* allocate and add a hook to our list. Used for all 4 types */
@@ -755,13 +772,13 @@ void *
 xchat_unhook (xchat_plugin *ph, xchat_hook *hook)
 {
 	/* perl.c trips this */
-	if (hook->type == HOOK_DELETED || !g_slist_find (hook_list, hook))
+	if (!g_slist_find (hook_list, hook) || hook->type == HOOK_DELETED)
 		return NULL;
 
 	if (hook->type == HOOK_TIMER && hook->tag != 0)
 		fe_timeout_remove (hook->tag);
 
-	if (hook->type == HOOK_FD)
+	if (hook->type == HOOK_FD && hook->tag != 0)
 		fe_input_remove (hook->tag);
 
 	hook->type = HOOK_DELETED;	/* expunge later */
@@ -898,6 +915,32 @@ xchat_set_context (xchat_plugin *ph, xchat_context *context)
 	return 0;
 }
 
+void xchat_find_set_context(xchat_plugin *ph)
+{
+	xchat_list *channels_list;
+	channels_list = xchat_list_get (ph, "channels");
+
+	if (channels_list == NULL)
+		return;
+
+	while (xchat_list_next (ph, channels_list)) {
+		const gchar *channel, *server;
+		gint type;
+
+		channel = xchat_list_str (ph, channels_list, "channel");
+		server  = xchat_list_str (ph, channels_list, "server");
+		type    = xchat_list_int (ph, channels_list, "type");
+
+		if (type == 1) {
+			xchat_context *context = xchat_find_context (ph, server, channel);
+			if (is_session(context)) {
+				xchat_set_context (ph, context);
+				return;
+			}
+		}
+	}
+}
+
 xchat_context *
 xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
 {
@@ -931,12 +974,16 @@ xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
 				{
 					if (rfc_casecmp (channel, sess->channel) == 0)
 					{
-						if (sess->server == ph->context->server)
-						{
-							g_slist_free (sessions);
-							return sess;
-						} else
-						{
+						if (ph->context != NULL) {
+							if (sess->server == ph->context->server)
+							{
+								g_slist_free (sessions);
+								return sess;
+							} else
+							{
+								sessions = g_slist_prepend (sessions, sess);
+							}
+						} else {
 							sessions = g_slist_prepend (sessions, sess);
 						}
 					}
@@ -962,26 +1009,19 @@ const char *
 xchat_get_info (xchat_plugin *ph, const char *id)
 {
 	session *sess;
-	guint32 hash = str_hash (id);
+	guint32 hash;
 
-	/* do the session independant ones first */
-	switch (hash)
+	/*                 1234567890 */
+	if (!strncmp (id, "event_text", 10))
 	{
-	case 0x325acab5:	/* libdirfs */
-		return XCHATLIBDIR;
-
-	case 0x14f51cd8: /* version */
-		return PACKAGE_VERSION;
-
-	case 0xdd9b1abd:	/* xchatdir */
-		return get_xdir_utf8 ();
-
-	case 0xe33f6c4a:	/* xchatdirfs */
-		return get_xdir_fs ();
+		char *e = (char *)id + 10;
+		if (*e == ' ') e++;	/* 2.8.0 only worked without a space */
+		return text_find_format_string (e);
 	}
 
+	hash = str_hash (id);
 	/* do the session independant ones first */
-	switch (str_hash (id))
+	switch (hash)
 	{
 	case 0x325acab5:	/* libdirfs */
 		return XCHATLIBDIR;
@@ -1031,6 +1071,9 @@ xchat_get_info (xchat_plugin *ph, const char *id)
 	case 0x1c0e99c1: /* inputbox */
 		return fe_get_inputbox_contents (sess);
 
+	case 0x633fb30:	/* modes */
+		return sess->current_modes;
+
 	case 0x6de15a2e:	/* network */
 		return server_get_network (sess->server, FALSE);
 
@@ -1411,7 +1454,9 @@ xchat_list_int (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		case 0xd1b:	/* id */
 			return ((struct session *)data)->server->id;
 		case 0x5cfee87:	/* flags */
-			tmp = ((struct session *)data)->beep;            /* bit 8 */
+			tmp = ((struct session *)data)->tray;            /* bit 9 */
+			tmp <<= 1;
+			tmp |= ((struct session *)data)->beep;               /* 8 */
 			tmp <<= 1;
 			tmp |= ((struct session *)data)->color_paste;        /* 7 */
 			tmp <<= 1;
