@@ -22,7 +22,6 @@
 #include <config.h>
 #include <glib/gi18n.h>
 #include <string.h>
-#include <libgnome/libgnome.h>
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -76,6 +75,7 @@ static void on_help_contents_activate (GtkAction *action, gpointer data);
 static void on_help_about_activate (GtkAction *action, gpointer data);
 static void on_nickname_clicked (GtkButton *widget, gpointer user_data);
 static void on_users_toggled (GtkToggleButton *widget, gpointer user_data);
+static void on_sidebar_toggled (GtkToggleAction *action, gpointer user_data);
 
 static void on_add_widget (GtkUIManager *manager, GtkWidget *menu, GtkWidget *menu_vbox);
 
@@ -85,6 +85,8 @@ static gboolean on_hpane_move (GtkPaned *widget, GParamSpec *param_spec, gpointe
 static gboolean on_main_window_focus_in (GtkWidget *widget, GdkEventFocus *event, gpointer data);
 static gboolean on_main_window_configure (GtkWidget *widget, GdkEventConfigure *event, gpointer data);
 
+static gboolean on_main_window_window_state (GtkWidget *widget, GdkEventWindowState *event, gpointer data);
+
 static void nickname_style_set (GtkWidget *button, GtkStyle *previous_style, gpointer data);
 
 static GtkActionEntry action_entries [] = {
@@ -95,39 +97,45 @@ static GtkActionEntry action_entries [] = {
 	{ "Insert",      NULL, N_("In_sert") },
 	{ "Network",     NULL, N_("_Network") },
 	{ "Discussion",  NULL, N_("_Discussion") },
-	{ "Go",          NULL, N_("_Go") },
+	{ "View",        NULL, N_("_View") },
 	{ "Help",        NULL, N_("_Help") },
 	{ "PopupAction", NULL, "" },
 
 	/* IRC menu */
-	{ "IRCConnect",   NULL,           N_("_Connect..."),        "<control>N", NULL, G_CALLBACK (on_irc_connect_activate) },
-	{ "IRCDownloads", NULL,           N_("_File Transfers"), "<alt>F",     NULL, G_CALLBACK (on_irc_downloads_activate) },
-	{ "IRCQuit",      GTK_STOCK_QUIT, N_("_Quit"),           "<control>Q", NULL, G_CALLBACK (on_irc_quit_activate) },
+	{ "IRCConnect",   NULL,           N_("_Connect..."),     "<control>N", NULL, G_CALLBACK(on_irc_connect_activate) },
+	{ "IRCDownloads", NULL,           N_("_File Transfers"), "<alt>F",     NULL, G_CALLBACK(on_irc_downloads_activate) },
+	{ "IRCQuit",      GTK_STOCK_QUIT, N_("_Quit"),           "<control>Q", NULL, G_CALLBACK(on_irc_quit_activate) },
 
 	/* Edit menu */
-	{ "EditCut",         GTK_STOCK_CUT,         N_("Cu_t"),         "<control>X", NULL, G_CALLBACK (on_edit_cut_activate) },
-	{ "EditCopy",        GTK_STOCK_COPY,        N_("_Copy"),        "<control>C", NULL, G_CALLBACK (on_edit_copy_activate) },
-	{ "EditPaste",       GTK_STOCK_PASTE,       N_("_Paste"),       "<control>V", NULL, G_CALLBACK (on_edit_paste_activate) },
-	{ "EditPreferences", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), "",           NULL, G_CALLBACK (on_edit_preferences_activate) },
+	{ "EditCut",         GTK_STOCK_CUT,         N_("Cu_t"),         "<control>X", NULL, G_CALLBACK(on_edit_cut_activate) },
+	{ "EditCopy",        GTK_STOCK_COPY,        N_("_Copy"),        "<control>C", NULL, G_CALLBACK(on_edit_copy_activate) },
+	{ "EditPaste",       GTK_STOCK_PASTE,       N_("_Paste"),       "<control>V", NULL, G_CALLBACK(on_edit_paste_activate) },
+	{ "EditPreferences", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), "",           NULL, G_CALLBACK(on_edit_preferences_activate) },
 
 	/* Network menu */
-	{ "NetworkReconnect",   GTK_STOCK_REFRESH,     N_("_Reconnect"),   "<control>R",        NULL, G_CALLBACK (on_network_reconnect_activate) },
-	{ "NetworkDisconnect",  GTK_STOCK_DISCONNECT,  N_("_Disconnect"),  "",                  NULL, G_CALLBACK (on_network_disconnect_activate) },
-	{ "NetworkClose",       GTK_STOCK_CLOSE,       N_("_Close"),       "<shift><control>W", NULL, G_CALLBACK (on_close_activate) },
-	{ "NetworkChannels",    NULL,                  N_("_Channels..."), "<alt>C",            NULL, G_CALLBACK (on_network_channels_activate) },
+	{ "NetworkReconnect",   GTK_STOCK_REFRESH,     N_("_Reconnect"),   "<control>R",        NULL, G_CALLBACK(on_network_reconnect_activate) },
+	{ "NetworkDisconnect",  GTK_STOCK_DISCONNECT,  N_("_Disconnect"),  "",                  NULL, G_CALLBACK(on_network_disconnect_activate) },
+	{ "NetworkClose",       GTK_STOCK_CLOSE,       N_("_Close"),       "<shift><control>W", NULL, G_CALLBACK(on_close_activate) },
+	{ "NetworkChannels",    NULL,                  N_("_Channels..."), "<alt>C",            NULL, G_CALLBACK(on_network_channels_activate) },
 
 	/* Discussion menu */
-	{ "DiscussionSave",        GTK_STOCK_SAVE,           N_("_Save Transcript"), "<control>S", NULL, G_CALLBACK (on_discussion_save_activate) },
-	{ "DiscussionLeave",       GTK_STOCK_QUIT,           N_("_Leave"),           "",           NULL, G_CALLBACK (on_discussion_leave_activate) },
-	{ "DiscussionClose",       GTK_STOCK_CLOSE,          N_("Cl_ose"),           "<control>W", NULL, G_CALLBACK (on_close_activate) },
-	{ "DiscussionFind",        GTK_STOCK_FIND,           N_("_Find"),            "<control>F", NULL, G_CALLBACK (on_discussion_find_activate) },
-	{ "DiscussionChangeTopic", NULL,                     N_("Change _Topic"),    "<alt>T",     NULL, G_CALLBACK (on_discussion_topic_change_activate) },
-	{ "DiscussionBans",        GTK_STOCK_DIALOG_WARNING, N_("_Bans..."),         "<alt>B",     NULL, G_CALLBACK (on_discussion_bans_activate) },
-	{ "DiscussionUsers",       NULL,                     N_("_Users"),           "<control>U", NULL, G_CALLBACK (on_discussion_users_activate) },
+	{ "DiscussionSave",        GTK_STOCK_SAVE,           N_("_Save Transcript"), "<control>S", NULL, G_CALLBACK(on_discussion_save_activate) },
+	{ "DiscussionLeave",       GTK_STOCK_QUIT,           N_("_Leave"),           "",           NULL, G_CALLBACK(on_discussion_leave_activate) },
+	{ "DiscussionClose",       GTK_STOCK_CLOSE,          N_("Cl_ose"),           "<control>W", NULL, G_CALLBACK(on_close_activate) },
+	{ "DiscussionFind",        GTK_STOCK_FIND,           N_("_Find"),            "<control>F", NULL, G_CALLBACK(on_discussion_find_activate) },
+	{ "DiscussionChangeTopic", NULL,                     N_("Change _Topic"),    "<alt>T",     NULL, G_CALLBACK(on_discussion_topic_change_activate) },
+	{ "DiscussionBans",        GTK_STOCK_DIALOG_WARNING, N_("_Bans..."),         "<alt>B",     NULL, G_CALLBACK(on_discussion_bans_activate) },
+	{ "DiscussionUsers",       NULL,                     N_("_Users"),           "<control>U", NULL, G_CALLBACK(on_discussion_users_activate) },
 
 	/* Help menu */
-	{ "HelpContents", GTK_STOCK_HELP,  N_("_Contents"), "F1", NULL, G_CALLBACK (on_help_contents_activate) },
-	{ "HelpAbout",    GTK_STOCK_ABOUT, N_("_About"),    NULL, NULL, G_CALLBACK (on_help_about_activate) },
+	{ "HelpContents", GTK_STOCK_HELP,  N_("_Contents"), "F1", NULL, G_CALLBACK(on_help_contents_activate) },
+	{ "HelpAbout",    GTK_STOCK_ABOUT, N_("_About"),    NULL, NULL, G_CALLBACK(on_help_about_activate) },
+};
+
+static const GtkToggleActionEntry toggle_action_entries [] =
+{
+	/* View menu */
+	{ "ViewShowSidebar", NULL, N_("_Sidebar"), "F9", "", G_CALLBACK (on_sidebar_toggled), TRUE }
 };
 
 void
@@ -141,12 +149,15 @@ initialize_main_window (void)
 	g_signal_connect (G_OBJECT (gui.main_window), "delete-event",    G_CALLBACK (on_main_window_close),     NULL);
 	g_signal_connect (G_OBJECT (gui.main_window), "focus-in-event",  G_CALLBACK (on_main_window_focus_in),  NULL);
 	g_signal_connect (G_OBJECT (gui.main_window), "configure-event", G_CALLBACK (on_main_window_configure), NULL);
+	g_signal_connect (G_OBJECT (gui.main_window), "window-state-event", G_CALLBACK (on_main_window_window_state), NULL);
 
 	/* hook up the menus */
 	gui.action_group = gtk_action_group_new ("MenuAction");
 	gtk_action_group_set_translation_domain (gui.action_group, NULL);
 	gtk_action_group_add_actions (gui.action_group, action_entries,
 	                              G_N_ELEMENTS (action_entries), NULL);
+	gtk_action_group_add_toggle_actions (gui.action_group, toggle_action_entries,
+					     G_N_ELEMENTS (toggle_action_entries), NULL);
 
 	gtk_ui_manager_insert_action_group (gui.manager, gui.action_group, 0);
 
@@ -219,33 +230,50 @@ initialize_main_window (void)
 void
 run_main_window ()
 {
-	GtkWidget *pane;
-	GConfClient *client;
-	int width, height;
-	int x, y;
-	int h;
+	GConfClient *client = gconf_client_get_default();
 
-	client = gconf_client_get_default ();
-	width  = gconf_client_get_int (client, "/apps/xchat/main_window/width",  NULL);
-	height = gconf_client_get_int (client, "/apps/xchat/main_window/height", NULL);
+	int width = gconf_client_get_int(client,
+	                                 "/apps/xchat/main_window/width",
+	                                 NULL);
+	int height = gconf_client_get_int(client,
+	                                  "/apps/xchat/main_window/height",
+	                                  NULL);
 	if (width == 0 || height == 0) {
-		gtk_window_set_default_size (GTK_WINDOW (gui.main_window), 800, 550);
-	} else {
-		gtk_window_set_default_size (GTK_WINDOW (gui.main_window), width, height);
+		width = 800;
+		height = 550;
 	}
-	x = gconf_client_get_int (client, "/apps/xchat/main_window/x", NULL);
-	y = gconf_client_get_int (client, "/apps/xchat/main_window/y", NULL);
+	gtk_window_set_default_size(GTK_WINDOW(gui.main_window), width, height);
+
+	int x = gconf_client_get_int (client, "/apps/xchat/main_window/x", NULL);
+	int y = gconf_client_get_int (client, "/apps/xchat/main_window/y", NULL);
 	if (!(x == 0 || y == 0)) {
-		gtk_window_move (GTK_WINDOW (gui.main_window), x, y);
+		gtk_window_move (GTK_WINDOW(gui.main_window), x, y);
 	}
-	h = gconf_client_get_int (client, "/apps/xchat/main_window/hpane", NULL);
-	if(h != 0) {
-		GtkWidget *hpane = glade_xml_get_widget (gui.xml, "HPane");
-		gtk_paned_set_position (GTK_PANED (hpane), h);
+
+	int h = gconf_client_get_int(client,
+	                             "/apps/xchat/main_window/hpane",
+	                             NULL);
+	if (h != 0) {
+		GtkWidget *hpane = glade_xml_get_widget(gui.xml, "HPane");
+		gtk_paned_set_position(GTK_PANED(hpane), h);
 	}
-	g_signal_connect (G_OBJECT (gui.main_window), "configure-event", G_CALLBACK (on_resize), NULL);
-	pane = glade_xml_get_widget (gui.xml, "HPane");
-	g_signal_connect (G_OBJECT (pane), "notify::position", G_CALLBACK (on_hpane_move), NULL);
+	g_signal_connect(G_OBJECT(gui.main_window), "configure-event",
+	                 G_CALLBACK(on_resize), NULL);
+
+	GtkWidget *pane = glade_xml_get_widget (gui.xml, "HPane");
+	g_signal_connect(G_OBJECT(pane), "notify::position",
+	                 G_CALLBACK(on_hpane_move), NULL);
+
+
+	GtkAction *action = gtk_action_group_get_action(gui.action_group,
+	                                                "ViewShowSidebar");
+	gboolean sidebar =
+		gconf_client_get_bool(client,
+		                      "/apps/xchat/main_window/show_hpane",
+		                      NULL);
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), sidebar);
+
+
 	g_object_unref (client);
 
 	gtk_widget_show (gui.main_window);
@@ -473,7 +501,9 @@ on_help_contents_activate (GtkAction *action, gpointer data)
 {
 	GError *error = NULL;
 
-	gnome_help_display_with_doc_id (NULL, "xchat-gnome", "xchat-gnome.xml", NULL, &error);
+	gtk_show_uri (gtk_widget_get_screen (gui.main_window),
+		      "ghelp:xchat-gnome",
+		      gtk_get_current_event_time (), &error);
 	if (error) {
 		error_dialog (_("Error showing help"), error->message);
 		g_error_free (error);
@@ -486,6 +516,29 @@ on_help_about_activate (GtkAction *action, gpointer data)
 	show_about_dialog ();
 }
 
+static void
+on_sidebar_toggled (GtkToggleAction *action, gpointer data)
+{
+	GConfClient *client;
+	GtkWidget *paned, *child;
+
+	client = gconf_client_get_default();
+	gconf_client_set_bool(client,
+	                      "/apps/xchat/main_window/show_hpane",
+	                      gtk_toggle_action_get_active(action),
+	                      NULL);
+	g_object_unref(client);
+
+	paned = glade_xml_get_widget(gui.xml, "HPane");
+	child = gtk_paned_get_child1(GTK_PANED(paned));
+
+	if (gtk_toggle_action_get_active(action)) {
+		gtk_widget_show(child);
+	} else {
+		gtk_widget_hide(child);
+	}
+}
+
 static void
 nickname_dialog_entry_activated (GtkEntry *entry, GtkDialog *dialog)
 {
@@ -495,52 +548,57 @@ nickname_dialog_entry_activated (GtkEntry *entry, GtkDialog *dialog)
 static void
 on_nickname_clicked (GtkButton *widget, gpointer user_data)
 {
-	GtkWidget *dialog;
-	GtkWidget *entry, *away;
-	gint result;
-
 	if (gui.current_session == NULL) {
 		return;
 	}
 	current_sess = gui.current_session;
 
-	dialog = glade_xml_get_widget (gui.xml, "nickname dialog");
-	entry = glade_xml_get_widget (gui.xml, "nickname dialog entry");
-	away = glade_xml_get_widget (gui.xml, "nickname dialog away");
+	GtkWidget *dialog = glade_xml_get_widget (gui.xml, "nickname dialog");
+	GtkWidget *entry = glade_xml_get_widget (gui.xml, "nickname dialog entry");
+	GtkWidget *away_button = glade_xml_get_widget (gui.xml, "nickname dialog away");
 
-	gtk_entry_set_text (GTK_ENTRY (entry), current_sess->server->nick);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (away), current_sess->server->is_away);
-	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (nickname_dialog_entry_activated), dialog);
+	gtk_entry_set_text(GTK_ENTRY(entry), current_sess->server->nick);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(away_button), current_sess->server->is_away);
+	g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(nickname_dialog_entry_activated), dialog);
 
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	gint result = gtk_dialog_run(GTK_DIALOG(dialog));
 	if (result == GTK_RESPONSE_OK) {
 		GtkWidget *check_all;
 		gboolean all;
 		gchar *text, *buf;
 
-		check_all = glade_xml_get_widget (gui.xml, "nickname dialog all");
-		all = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_all));
+		check_all = glade_xml_get_widget(gui.xml, "nickname dialog all");
+		all = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (check_all));
 
 		/* Nick */
-		text = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
+		text = (gchar *) gtk_entry_get_text(GTK_ENTRY (entry));
 		if (all) {
-			buf = g_strdup_printf ("allserv nick %s", text);
+			buf = g_strdup_printf("allserv nick %s", text);
 		} else {
-			buf = g_strdup_printf ("nick %s", text);
+			buf = g_strdup_printf("nick %s", text);
 		}
-		handle_command (current_sess, buf, FALSE);
+		handle_command(current_sess, buf, FALSE);
 		g_free (buf);
 
 		/* Away */
-		if (current_sess->server->is_away != gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (away))) {
-			if (all) {
-				handle_command (current_sess, "allserv away", FALSE);
+		gboolean away = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(away_button));
+		if (current_sess->server->is_away != away) {
+			if (away) {
+				if (all) {
+					handle_command(current_sess, "allserv away", FALSE);
+				} else {
+					handle_command(current_sess, "away", FALSE);
+				}
 			} else {
-				handle_command (current_sess, "away", FALSE);	
+				if (all) {
+					handle_command(current_sess, "allserv back", FALSE);
+				} else {
+					handle_command(current_sess, "back", FALSE);
+				}
 			}
 		}
 	}
-	gtk_widget_hide (dialog);
+	gtk_widget_hide(dialog);
 }
 
 static gboolean
@@ -664,6 +722,20 @@ on_main_window_configure (GtkWidget *widget, GdkEventConfigure *event, gpointer
 	return FALSE;
 }
 
+static gboolean
+on_main_window_window_state (GtkWidget *widget, GdkEventWindowState *event, gpointer data)
+{
+	if (event->changed_mask & GDK_WINDOW_STATE_MAXIMIZED)
+	{
+		if (event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED)
+			gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (gui.status_bar), FALSE);
+		else
+			gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (gui.status_bar), TRUE);
+	}
+
+	return FALSE;
+}
+
 static void
 nickname_style_set (GtkWidget *button, GtkStyle *previous_style, gpointer data)
 {
