@@ -35,7 +35,7 @@ G_DEFINE_TYPE(PreferencesPageColors, preferences_page_colors, PREFERENCES_PAGE_T
 static int scheme;
 
 static void
-show_colors_changed (GtkToggleButton *button, const gchar *key)
+toggle_pref_changed (GtkToggleButton *button, const gchar *key)
 {
 	GConfClient *client;
 	gboolean value;
@@ -144,14 +144,14 @@ colors_changed (GtkComboBox *combo_box, PreferencesPageColors *page)
 }
 
 static void
-gconf_show_colors_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, GtkToggleButton *button)
+gconf_toggle_pref_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, GtkToggleButton *button)
 {
 	gboolean toggle;
 
-	g_signal_handlers_block_by_func (button, "toggled", show_colors_changed);
+	g_signal_handlers_block_by_func (button, "toggled", toggle_pref_changed);
 	toggle = gconf_client_get_bool (client, entry->key, NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), toggle);
-	g_signal_handlers_unblock_by_func (button, "toggled", show_colors_changed);
+	g_signal_handlers_unblock_by_func (button, "toggled", toggle_pref_changed);
 }
 
 static void
@@ -180,6 +180,7 @@ preferences_page_colors_new (gpointer prefs_dialog, GladeXML *xml)
 
 #define GW(name) ((page->name) = glade_xml_get_widget (xml, #name))
 	GW(show_colors);
+	GW(colorize_nicknames);
 	GW(color_label_1);
 	GW(color_label_2);
 	GW(color_label_3);
@@ -241,7 +242,8 @@ preferences_page_colors_new (gpointer prefs_dialog, GladeXML *xml)
 	gtk_label_set_mnemonic_widget (GTK_LABEL (page->color_label_4), page->color_buttons[2]);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (page->color_label_5), page->color_buttons[3]);
 
-	g_signal_connect (G_OBJECT (page->show_colors),      "toggled",   G_CALLBACK (show_colors_changed),  "/apps/xchat/irc/showcolors");
+	g_signal_connect (G_OBJECT (page->show_colors),        "toggled", G_CALLBACK (toggle_pref_changed), "/apps/xchat/irc/showcolors");
+	g_signal_connect (G_OBJECT (page->colorize_nicknames), "toggled", G_CALLBACK (toggle_pref_changed), "/apps/xchat/irc/colorize_nicknames");
 	g_signal_connect (G_OBJECT (page->color_buttons[0]), "color-set", G_CALLBACK (color_button_changed), GINT_TO_POINTER (32));
 	g_signal_connect (G_OBJECT (page->color_buttons[1]), "color-set", G_CALLBACK (color_button_changed), GINT_TO_POINTER (33));
 	g_signal_connect (G_OBJECT (page->color_buttons[2]), "color-set", G_CALLBACK (color_button_changed), GINT_TO_POINTER (34));
@@ -263,12 +265,16 @@ preferences_page_colors_new (gpointer prefs_dialog, GladeXML *xml)
 	scheme = gconf_client_get_int (p->gconf, "/apps/xchat/irc/color_scheme", NULL);
 
 	page->nh[0] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/showcolors",
-	                                       (GConfClientNotifyFunc) gconf_show_colors_changed, page->show_colors, NULL, NULL);
-	page->nh[1] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/color_scheme",
+	                                       (GConfClientNotifyFunc) gconf_toggle_pref_changed, page->show_colors, NULL, NULL);
+	page->nh[1] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/colorize_nicknames",
+					       (GConfClientNotifyFunc) gconf_toggle_pref_changed, page->colorize_nicknames, NULL, NULL);			       
+	page->nh[2] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/color_scheme",
 	                                       (GConfClientNotifyFunc) gconf_color_changed, page, NULL, NULL);
 
 	toggle = gconf_client_get_bool (p->gconf, "/apps/xchat/irc/showcolors", NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->show_colors), toggle);
+	toggle = gconf_client_get_bool (p->gconf, "/apps/xchat/irc/colorize_nicknames", NULL);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->colorize_nicknames), toggle);
 
 	g_signal_connect (G_OBJECT (page->combo), "changed", G_CALLBACK (colors_changed), page);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (page->combo), scheme);
@@ -289,7 +295,7 @@ preferences_page_colors_finalize (GObject *object)
 	GConfClient *client;
 
 	client = gconf_client_get_default ();
-	for (i = 0; i < 2; i++) {
+	for (i = 0; i < 3; i++) {
 		gconf_client_notify_remove (client, page->nh[i]);
 	}
 	g_object_unref (client);
