@@ -91,6 +91,21 @@ text_entry_class_init (TextEntryClass *klass)
 	widget_class->grab_focus = text_entry_grab_focus;
 }
 
+/* copied from eel-glib-extensions.c */
+
+static GList *
+g_list_from_g_slist (GSList *slist)
+{
+	GList *list;
+	GSList *node;
+
+	list = NULL;
+	for (node = slist; node != NULL; node = node->next) {
+		list = g_list_prepend (list, node->data);
+	}
+	return g_list_reverse (list);
+}
+
 static void
 text_entry_init (TextEntry *entry)
 {
@@ -100,6 +115,7 @@ text_entry_init (TextEntry *entry)
 	gboolean enable_spellcheck;
 	GSList *languages;
 	GError *err  = NULL;
+	GList *real_command_list;
 
 	g_signal_connect_after (G_OBJECT (entry), "key_press_event",         G_CALLBACK (text_entry_key_press),         NULL);
 	g_signal_connect       (G_OBJECT (entry), "activate",                G_CALLBACK (text_entry_activate),          NULL);
@@ -112,7 +128,9 @@ text_entry_init (TextEntry *entry)
 
 	/* Initialize & populate a GCompletion for commands */
 	entry->priv->command_completion = g_completion_new (NULL);
-	g_completion_add_items (entry->priv->command_completion, command_list);
+	real_command_list = g_list_from_g_slist (command_list);
+	g_completion_add_items (entry->priv->command_completion, real_command_list);
+	g_list_free (real_command_list);
 	for (i = 0; xc_cmds[i].name != NULL; i++) {
 		items = g_list_prepend (items, xc_cmds[i].name);
 	}
@@ -477,7 +495,7 @@ tab_complete_command (GtkEntry *entry)
 			g_free (printtext);
 			printtext = npt;
 		}
-		conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel), text_entry->priv->current, (guchar *) printtext, TRUE);
+		conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel), text_entry->priv->current, printtext, TRUE);
 		g_free (printtext);
 
 		if (new_prefix && strcasecmp (prefix, new_prefix) != 0) {
@@ -580,7 +598,7 @@ tab_complete_nickname (GtkEntry *entry, gint start)
 			g_free (printtext);
 			printtext = npt;
 		}
-		conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel), text_entry->priv->current, (guchar *) printtext, TRUE);
+		conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel), text_entry->priv->current, printtext, TRUE);
 		g_free (printtext);
 
 		if (strcasecmp (prefix, new_prefix) != 0) {
@@ -626,7 +644,7 @@ static void
 color_code_activate (GtkMenuItem *item, gpointer data)
 {
 	int color = GPOINTER_TO_INT (data);
-	char *code = g_strdup_printf ("%%C%d", color);
+	char *code = g_strdup_printf ("\003%d", color);
 	int position = gtk_editable_get_position (GTK_EDITABLE (gui.text_entry));
 	gtk_editable_insert_text (GTK_EDITABLE (gui.text_entry), code, strlen (code), &position);
 	gtk_editable_set_position (GTK_EDITABLE (gui.text_entry), position + strlen (code));
